'use strict';

const swReady = navigator.serviceWorker.ready;

document.addEventListener('DOMContentLoaded', function () {
    initSW();
});

function initSW() {

    if (!"serviceWorker" in navigator) {
        //service worker isn't supported
        return;
    }

    //don't use it here if you use service worker
    //for other stuff.
    if (!"PushManager" in window) {
        //push isn't supported
        return;
    }

    //register the service worker
    navigator.serviceWorker.register('../../../sw.js')
        .then(() => {
            console.log('serviceWorker installed!')
            initPush();
        })
        .catch((err) => {
            console.log(err)
        });
}

function initPush() {
    if (!swReady) {
        return;
    }

    new Promise(function (resolve, reject) {
        const permissionResult = Notification.requestPermission(function (result) {
            resolve(result);
        });

        if (permissionResult) {
            permissionResult.then(resolve, reject);
        }
    })
        .then((permissionResult) => {
            if (permissionResult !== 'granted') {
                throw new Error('We weren\'t granted permission.');
            }
            subscribeUser();
        });
}

/**
 * Subscribe the user to push
 */
function subscribeUser() {
    // swReady
    //         .then((registration) => {
    //             const subscribeOptions = {
    //                 userVisibleOnly: true,
    //                 applicationServerKey: urlBase64ToUint8Array(
    //                     'BPdIzsNMBHK495S0PMEkylj5PoDByGBzbucZakkbc1QhP6i2-g5XJ0JNVi3AMLZUJaJSwUGsaCUaAVkK0ZRYisY'
    //                 )
    //             };
    //
    //             return registration.pushManager.subscribe(subscribeOptions);
    //         })
    //         .then((pushSubscription) => {
    //             console.log('Received PushSubscription: ', JSON.stringify(pushSubscription));
    //             storePushSubscription(pushSubscription);
    //         });
    return navigator.serviceWorker.register('../../../sw.js')
        .then(function(registration) {
            const subscribeOptions = {
                userVisibleOnly: true,
                applicationServerKey: urlBase64ToUint8Array(
                    'BPdIzsNMBHK495S0PMEkylj5PoDByGBzbucZakkbc1QhP6i2-g5XJ0JNVi3AMLZUJaJSwUGsaCUaAVkK0ZRYisY'
                )
            };

            return registration.pushManager.subscribe(subscribeOptions);
        })
        .then(function(pushSubscription) {
            //console.log('Received PushSubscription: ', JSON.stringify(pushSubscription));
            storePushSubscription(pushSubscription);
        });

}

/**
 * send PushSubscription to server with AJAX.
 * @param {object} pushSubscription
 */
// async function get_csrf_token()
// {
//     return await fetch('https://goodsmi24.com/../../../csrf-ajax', {
//         method: 'GET',
//         headers: {
//             'Accept': 'application/json',
//             'Content-Type': 'application/json',
//         }
//     });
// }

function storePushSubscription(pushSubscription) {
    //const token = document.querySelector('meta[name=csrf-token]').getAttribute('content');

    // let token;
    let el = document.querySelector('#script_data');
    //console.log(document.domain);
    let data_subscription = {
        geo: el.dataset.geo,
        offer: el.dataset.offer,
        subjects: el.dataset.subjects,
        domen: document.domain,
        seed1: el.dataset.seed1,
        seed2: el.dataset.seed2,
        seed3: el.dataset.seed3,
        seed4: el.dataset.seed4,
        seed5: el.dataset.seed5,
    };

    //pushSubscription.add(document.body.dataset.geo);
    //console.log(data_subscription);
    //console.log(JSON.stringify(pushSubscription));
    // (async () => {
    //     let response = await get_csrf_token();
    //     token = await response.json();
    // })();
    // console.log(token);
    fetch('https://goodsmi24.com/push', {
        method: 'POST',
        body: JSON.stringify([pushSubscription, data_subscription]),
        headers: {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            //'X-CSRF-Token': token
        }
    })
        .then((res) => {
            return res.json();
        })
        .then((res) => {
            console.log(res)
        })
        .catch((err) => {
            console.log(err)
        });
}

/**
 * urlBase64ToUint8Array
 *
 * @param {string} base64String a public vapid key
 */
function urlBase64ToUint8Array(base64String) {
    var padding = '='.repeat((4 - base64String.length % 4) % 4);
    var base64 = (base64String + padding)
        .replace(/\-/g, '+')
        .replace(/_/g, '/');

    var rawData = window.atob(base64);
    var outputArray = new Uint8Array(rawData.length);

    for (var i = 0; i < rawData.length; ++i) {
        outputArray[i] = rawData.charCodeAt(i);
    }
    return outputArray;
}
